// Persistence of Vision Ray Tracer Sample Scene File
// Part of the IRTC GIP object archives

// Demonstrating Objects: IR_ParkFence and IR_ParkGate
// Author: Ib Rasmussen
// Date (yyyy-mm-dd): 2000.01.30

#include "colors.inc"
#include "stones1.inc"
#include "skies.inc"

#version 3.1;
global_settings { assumed_gamma 1.0 }

#declare R = seed(0);

/************************* Declarations ******************************/

/*--------------------- Camera and Lights ---------------------------*/
#declare CamX = -1900;
#declare CamY = 175;
#declare CamZ = -3000;

#declare TestCam=camera {
   location  <CamX, CamY, CamZ>
   angle 20
   look_at   <-650, 0,  1500 >
}

#declare PointLight=light_source { <0, 0, 0>, colour White }
#declare CamLight=light_source { <0, 0, 0>, colour White*0.4 }

/*-------------------------- Textures -------------------------------*/



/*------------------------- Objects ----------------------------------*/

#include "IR_ParkFence.inc"   

#declare BlueMan=union {
   cone { <0, 0, 0>, 15, <0, 150, 0>, 25 scale <1, 1, 15/25> }
   cone { <0, 150, 0>, 8, <0, 180, 0>, 9 }
   pigment { Blue }  
}

/***************************** Scene *********************************/

/*--------------- Camera, Lights and Background ---------------------*/

camera { TestCam }

object { PointLight translate <-17000, 17500, -28000> }
object { CamLight translate <CamX, CamY, CamZ> }

sky_sphere { S_Cloud1 }

/*------------------------- Objects ----------------------------------*/
         
plane { y, 0 translate <0, 0, 0> pigment { DarkGreen } }


object { IR_ParkFence( 2000, 1) rotate <0, -90, 0> translate <-1500, 0, -1000> }
object { IR_ParkFence( 2000, 1) rotate <0,  90, 0> translate < 1500, 0,  1000> }
object { IR_ParkFence( 2000, 1) rotate <0,   0, 0> translate <-1000, 0,  1500> }
object { IR_ParkFence( 2000, 1) rotate <0,   0, 0> translate <-1000, 0, -1500> }

object { IR_ParkGate rotate <0, -45, 0> translate <-1250, 0,  1250> }
object { IR_ParkGate rotate <0,  45, 0> translate < 1250, 0,  1250> }
object { IR_ParkGate rotate <0,  45, 0> translate <-1250, 0, -1250> }
object { IR_ParkGate rotate <0, -45, 0> translate < 1250, 0, -1250> }

// Figures to give a sense of proportions.
object { BlueMan translate <-1150, 0,  1150> }
object { BlueMan translate <-1150, 0, -1150> }
